@@ -1,8 +1,8 @@
 import base64
-from typing import Dict, List, Union
+from typing import Any, Dict, List, Optional, Sequence, Union
 
 from aleph_alpha_client.image import ImagePrompt
-from aleph_alpha_client.prompt_item import _to_prompt_item
+from aleph_alpha_client.prompt import _to_prompt_item
 
 
 class Document:
@@ -10,11 +10,17 @@ class Document:
     A document that can be either a docx document or text/image prompts.
     """
 
-    def __init__(self, docx: str = None, prompt: List[Union[str, ImagePrompt]] = None):
+    def __init__(
+        self,
+        docx: Optional[str] = None,
+        prompt: Optional[Sequence[Union[str, ImagePrompt]]] = None,
+        text: Optional[str] = None,
+    ):
         # We use a base_64 representation for docx documents, because we want to embed the file
         # into a prompt send in JSON.
         self.docx = docx
         self.prompt = prompt
+        self.text = text
 
     @classmethod
     def from_docx_bytes(cls, bytes: bytes):
@@ -34,7 +40,7 @@ class Document:
         return cls.from_docx_bytes(docx_bytes)
 
     @classmethod
-    def from_prompt(cls, prompt: List[Union[str, ImagePrompt]]):
+    def from_prompt(cls, prompt: Sequence[Union[str, ImagePrompt]]):
         """
         Pass a prompt that can contain multiple strings and Image prompts and prepare it to be used as a document
         """
@@ -45,10 +51,9 @@ class Document:
         """
         Pass a single text and prepare it to be used as a document
         """
-        prompt = [text]
-        return cls(prompt=prompt)
+        return cls(text=text)
 
-    def _to_serializable_document(self) -> Dict[str, str]:
+    def _to_serializable_document(self) -> Dict[str, Any]:
         """
         A dict if serialized to JSON is suitable as a document element
         """
@@ -61,3 +66,9 @@ class Document:
             # Serialize prompt to Document JSON format
             prompt_data = [_to_prompt_item(prompt_item) for prompt_item in self.prompt]
             return {"prompt": prompt_data}
+        elif self.text is not None:
+            return {
+                "text": self.text,
+            }
+        else:
+            raise NotImplementedError("unsupported document type")
